@@ -1,42 +1,30 @@
-#! /usr/local/bin/perl 
+#!/usr/bin/perl 
 
 =head1 NAME
 
-findLeastCommonSubsumer.pl - this programs retuns the 
-the least common subsummer between two concepts.
+findLeastCommonSubsumer.pl - program finds the least common subsumer 
+between two concepts
 
 =head1 SYNOPSIS
 
-This program takes in a CUIs and returns their least 
-common subsumer.
+This program takes two terms or CUIs and returns the least common
+subsumer between them.
 
 =head1 USAGE
 
-Usage: findLeastCommonSubsumer.pl [OPTIONS] CUI1 CUI2
+Usage: findLeastCommonSubsumer.pl [OPTIONS] [CUI1|TERM1] [CUI2|TERM2]
 
 =head1 INPUT
 
 =head2 Required Arguments:
 
-=head3 CUI1 and CUI2
+=head3 [CUI1|TERM1] [CUI2|TERM2]
 
-A concepts (CUIs) from the Unified Medical Language System
+A TERM or CUI (or some combination) from the Unified 
+Medical Language System
 
 =head2 Optional Arguments:
 
-=head3 --config FILE
-
-Configuration file to specify what sources and relations 
-in the UMLS that are to be included or excluded from use. 
-
-An example of the configuration file is as follows:
-
-SAB :: include SNOMEDCT, MSH
-
-REL :: include PAR, CHD, RN, RB
-
-
-
 =head3 --username STRING
 
 Username is required to access the umls database on MySql
@@ -85,7 +73,7 @@ List of CUIs that are associated with the input term
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008,
+Copyright (c) 2007-2009,
 
  Bridget T. McInnes, University of Minnesota
  bthomson at cs.umn.edu
@@ -93,6 +81,12 @@ Copyright (c) 2007-2008,
  Ted Pedersen, University of Minnesota Duluth
  tpederse at d.umn.edu
 
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd@cs.utah.edu
+ 
+ Serguei Pakhomov, University of Minnesota Twin Cities
+ pakh0002@umn.edu
+
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
 Foundation; either version 2 of the License, or (at your option) any later
@@ -124,7 +118,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s" );
+GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "cui" );
 
 
 #  if help is defined, print out help
@@ -141,9 +135,9 @@ if( defined $opt_version ) {
     exit;
 }
 
-# At least 1 term should be given on the command line.
-if(scalar(@ARGV) < 1) {
-    print STDERR "No term was specified on the command line";
+# At least 2 terms and/or cuis should be given on the command line.
+if(scalar(@ARGV) < 2) {
+    print STDERR "Two terms and/or CUIs are required\n";
     &minimalUsageNotes();
     exit;
 }
@@ -195,24 +189,77 @@ else {
 
 &errorCheck($umls);
 
-my $cui1 = shift;
-my $cui2 = shift;
 
-if($umls->validCui($cui1)) {
-    print STDERR "ERROR: The concept ($cui1) is not valid.\n";
-    exit;
+my $input1 = shift;
+my $input2 = shift;
+
+my $flag1 = "cui";
+my $flag2 = "cui";
+
+#  check if the input are CUIs or terms
+if( ($input1=~/C[0-9]+/)) {
+    push @c1, $input1;
+}
+else {
+    @c1 = $umls->getConceptList($input1); 
+    &errorCheck($umls);
+    $flag1 = "term";
+}
+if( ($input2=~/C[0-9]+/)) {
+    push @c2, $input2; 
+    $flag2 = "term";
+}
+else {
+    @c2 = $umls->getConceptList($input2); 
+    &errorCheck($umls);
+    $flag = "term";
 }
 
-if($umls->validCui($cui2)) {
-    print STDERR "ERROR: The concept ($cui2) is not valid.\n";
-    exit;
+my $printFlag = 0;
+
+foreach $cui1 (@c1) {
+    foreach $cui2 (@c2) {
+
+	if($umls->validCui($cui1)) {
+	    print STDERR "ERROR: The concept ($cui1) is not valid.\n";
+	    exit;
+	}
+
+	if($umls->validCui($cui2)) {
+	    print STDERR "ERROR: The concept ($cui2) is not valid.\n";
+	    exit;
+	}
+	
+	my $lcs = $umls->findLeastCommonSubsumer($cui1, $cui2);
+	
+	&errorCheck($umls);
+
+	my $t1 = $input1;
+	my $t2 = $input2;
+	
+	if($flag1 eq "term") {
+	    ($t1) = $umls->getTermList($cui1); 
+	}
+
+	if($flag2 eq "term") {
+	    ($t2) = $umls->getTermList($cui2); 
+	}
+	
+
+	my ($t) = $umls->getTermList($lcs);
+	
+	print "\nThe least common subsumer between $t1 ($cui1) and $t2 ($cui2) is $t ($lcs)\n";
+	
+	$printFlag = 1;
+    }
 }
 
-my $lcs = $umls->findLeastCommonSubsumer("$cui1", "$cui2");
-&errorCheck($umls);
-
-print "LCS of CUI1 ($cui1) and CUI2 ($cui2): $lcs\n";
-
+if( !($printFlag) ) {
+    print "\n";
+    print "There is not a least common subsumer between $input1 \n";
+    print "and $input2 given the current view of the UMLS.\n\n";
+}
+	
 sub errorCheck
 {
     my $obj = shift;
@@ -227,7 +274,7 @@ sub errorCheck
 ##############################################################################
 sub minimalUsageNotes {
     
-    print "Usage: findLeastCommonSubsumer.pl [OPTIONS] CUI1 CUI2\n\n";
+    print "Usage: findLeastCommonSubsumer.pl [OPTIONS] [CUI1|TERM1] [CUI2|TERM2]\n";
     &askHelp();
     exit;
 }
@@ -238,10 +285,10 @@ sub minimalUsageNotes {
 sub showHelp() {
 
         
-    print "This is a utility that takes as input two CUIs and returns\n";
-    print "their least common subsumer.\n";
+    print "This is a utility that takes as input two Terms or CUIs\n";
+    print "and returns the Least Common Subsumer between the two.\n\n";
   
-    print "Usage: findLeastCommonSubsumer.pl [OPTIONS] CUI1 CUI2\n\n";
+    print "Usage: findLeastCommonSubsumer.pl [OPTIONS] [CUI1|TERM1] [CUI2|TERM2]\n\n";
 
     print "Options:\n\n";
 
@@ -266,7 +313,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findLeastCommonSubsumer.pl,v 1.7 2009/01/25 00:19:40 btmcinnes Exp $';
+    print '$Id: findLeastCommonSubsumer.pl,v 1.10 2009/02/09 18:16:09 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
