@@ -11,22 +11,37 @@ path between them.
 
 =head1 USAGE
 
-Usage: findShortestPath.pl [OPTIONS] TERM1 TERM2
+Usage: findShortestPath.pl [OPTIONS] [CUI1|TERM1] [CUI2|TERM2]
 
 =head1 INPUT
 
 =head2 Required Arguments:
 
-=head3 TERM1 and TERM2
+=head3 [CUI1|TERM1] [CUI2|TERM2]
 
-A term in the Unified Medical Language System
+A TERM or CUI (or some combination) from the Unified 
+Medical Language System
 
 =head2 Optional Arguments:
 
-=head3 --cui 
+=head4 --infile FILE
+
+   A file containing pairs of concepts or terms in the following format:
+
+    term1<>term2 
+    
+    or 
+
+    cui1<>cui2
+ 
+    or 
+    
+    cui1<>term2
+
+    or 
+
+    term1<>cui2
 
-This flag indicates that TERM1 and TERM2 are actual CUIs 
-in the UMLS rather than associated terms
 
 =head3 --username STRING
 
@@ -60,7 +75,7 @@ Displays the version information.
 
 =head1 OUTPUT
 
-List of CUIs that are associated with the input term
+The path(s) between the two given CUIs or terms
 
 =head1 SYSTEM REQUIREMENTS
 
@@ -76,7 +91,7 @@ List of CUIs that are associated with the input term
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008,
+Copyright (c) 2007-2009,
 
  Bridget T. McInnes, University of Minnesota
  bthomson at cs.umn.edu
@@ -84,6 +99,12 @@ Copyright (c) 2007-2008,
  Ted Pedersen, University of Minnesota Duluth
  tpederse at d.umn.edu
 
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd@cs.utah.edu
+ 
+ Serguei Pakhomov, University of Minnesota Twin Cities
+ pakh0002@umn.edu
+
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
 Foundation; either version 2 of the License, or (at your option) any later
@@ -111,11 +132,10 @@ this program; if not, write to:
 #                            COMMAND LINE OPTIONS AND USAGE
 #                           ================================
 
-
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "cui" );
+GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "cui", "infile=s" );
 
 
 #  if help is defined, print out help
@@ -132,13 +152,6 @@ if( defined $opt_version ) {
     exit;
 }
 
-# At least 1 term should be given on the command line.
-if(scalar(@ARGV) < 1) {
-    print STDERR "No term was specified on the command line";
-    &minimalUsageNotes();
-    exit;
-}
-
 my $database = "umls";
 if(defined $opt_database) { $database = $opt_database; }
 my $hostname = "localhost";
@@ -186,86 +199,118 @@ else {
 
 &errorCheck($umls);
 
-
-my $input1 = shift;
-my $input2 = shift;
-
-my $flag = "cui";
-
-#  check if the input are CUIs or terms
-if(defined $opt_cui) {
-    push @c1, $input1;
-    push @c2, $input2;
+my @fileArray = ();
+if(defined $opt_infile) {
+    open(FILE, $opt_infile) || die "Could not open infile: $opt_infile\n";
+    while(<FILE>) {
+	chomp;
+	if($_=~/^\s*$/) { next; }
+	push @fileArray, $_;
+    }
+    close FILE;
 }
-elsif( ($input1=~/C[0-9]+/) || ($input1=~/C[0-9]+/) ) {
+else {
     
-    print "The input appear to be CUIs. Is this true (y/n)?\n";
-    my $answer = <STDIN>; chomp $answer;
-    if($answer=~/y/) {
-	print "Please specify the --cui option next time.\n";
+    # At least 2 terms and/or cuis should be given on the command line.
+    if(scalar(@ARGV) < 2) {
+	print STDERR "Two terms and/or CUIs are required\n";
+	&minimalUsageNotes();
+	exit;
+    }
+    
+
+    my $i1 = shift;
+    my $i2 = shift;
+
+    my $string = "$i1<>$i2";
+    push @fileArray, $string;
+}
+
+foreach my $element (@fileArray) {
+    
+    my ($input1, $input2) = split/<>/, $element;
+
+    print STDERR "$input1 $input2\n";
+    
+    my $flag1 = "cui";
+    my $flag2 = "cui";
+
+    #  check if the input are CUIs or terms
+    if( ($input1=~/C[0-9]+/)) {
 	push @c1, $input1;
-	push @c2, $input2;
     }
     else {
 	@c1 = $umls->getConceptList($input1); 
 	&errorCheck($umls);
+	$flag1 = "term";
+    }
+    if( ($input2=~/C[0-9]+/)) {
+	push @c2, $input2; 
+    }
+    else {
 	@c2 = $umls->getConceptList($input2); 
 	&errorCheck($umls);
-	$flag = "term";
+	$flag2 = "term";
     }
-}
-else {
-    @c1 = $umls->getConceptList($input1); 
-    &errorCheck($umls);
-    @c2 = $umls->getConceptList($input2); 
-    &errorCheck($umls);
-    $flag = "term";
-}
+    
+    
+    my $printFlag = 0;
+    
+    foreach $cui1 (@c1) {
+	foreach $cui2 (@c2) {
+	    
+	    if($umls->validCui($cui1)) {
+		print STDERR "ERROR: The concept ($cui1) is not valid.\n";
+		exit;
+	    }
+	    
+	    if($umls->validCui($cui2)) {
+		print STDERR "ERROR: The concept ($cui2) is not valid.\n";
+		exit;
+	    }
+	    if(! ($umls->checkConceptExists($cui1)) ) {
+		next; 
+	    }
+	    if(! ($umls->checkConceptExists($cui2)) ) {
+		next; 
+	    }
+		    
+	    my @shortestpath = $umls->findShortestPath($cui1, $cui2);
+	    
+	    &errorCheck($umls);
+	    
+	    if($#shortestpath < 0) { next; }
 
-my $printFlag = 0;
+	    my $t1 = $input1;
+	    my $t2 = $input2;
+	    
+	    if($flag1 eq "cui") {
+		($t1) = $umls->getTermList($cui1); 
+	    }
+	    
+	    if($flag2 eq "cui") {
+		($t2) = $umls->getTermList($cui2); 
+	    }
+	    
+	    print "\nThe shortest path between $t1 ($cui1) and $t2 ($cui2):\n";
+	    print "  => ";
+	    foreach my $concept (@shortestpath) {
+		my ($t) = $umls->getTermList($concept); 
+		print "$concept ($t) "; 
+	    }
+	    print "\n";
 
-foreach $cui1 (@c1)
-{
-    foreach $cui2 (@c2)
-    {
-
-	if($umls->validCui($cui1)) {
-	    print STDERR "ERROR: The concept ($cui1) is not valid.\n";
-	    exit;
-	}
-
-	if($umls->validCui($cui2)) {
-	    print STDERR "ERROR: The concept ($cui2) is not valid.\n";
-	    exit;
-	}
-	
-	my @shortestpath = $umls->findShortestPath($cui1, $cui2);
-	
-	&errorCheck($umls);
-	
-	if($flag eq "term") {
-	    print "\nThe shortest path between $cui1 ($input1) and $cui2 ($input2):\n";
-	}
-	else {
-	    print "\nThe shortest path between $cui1 and $cui2:\n";
-	}
-	print "  => ";
-	foreach my $concept (@shortestpath) {
-	    my ($t) = $umls->getTermList($concept); 
-	    print "$concept ($t) ";
+	    $printFlag = 1;
+	    
 	}
+    }
+    
+    if( !($printFlag) ) {
 	print "\n";
-
-	$printFlag = 1;
+	print "There is not a path between $input1 and $input2\n";
+	print "given the current view of the UMLS.\n\n";
     }
 }
-
-if( !($printFlag) ) {
-    print "\n";
-    print "There is not a path between $input1 and $input2\n";
-    print "given the current view of the UMLS.\n\n";
-}
-	
 sub errorCheck
 {
     my $obj = shift;
@@ -280,7 +325,7 @@ sub errorCheck
 ##############################################################################
 sub minimalUsageNotes {
     
-    print "Usage: findShortestPath.pl [OPTIONS] TERM1 TERM2\n\n";
+    print "Usage: findShortestPath.pl [OPTIONS] [CUI1|TERM1] [CUI2|TERM2]\n";
     &askHelp();
     exit;
 }
@@ -294,12 +339,11 @@ sub showHelp() {
     print "This is a utility that takes as input two Terms or\n";
     print "CUIs and returns the shortest path between them.\n\n";
   
-    print "Usage: findShortestPath.pl [OPTIONS] TERM1 TERM2\n\n";
+    print "Usage: findShortestPath.pl [OPTIONS] [CUI1|TERM1] [CUI2|TERM2]\n\n";
 
     print "Options:\n\n";
 
-    print "--cui                    Indicates that the input TERM1 and TERM2\n";
-    print "                         are Concept Unique Identifiers (CUIs).\n\n";
+    print "--infile FILE            File containing TERM or CUI pairs\n\n";
 
     print "--username STRING        Username required to access mysql\n\n";
 
@@ -322,7 +366,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findShortestPath.pl,v 1.7 2009/01/24 15:16:34 btmcinnes Exp $';
+    print '$Id: findShortestPath.pl,v 1.12 2009/02/09 18:16:09 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
