@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-getParents.pl - this program returns the parents of a concept
+getParents.pl - this program returns all of a concepts parents
 
 =head1 SYNOPSIS
 
@@ -11,15 +11,15 @@ given a specified set of sources.
 
 =head1 USAGE
 
-Usage: getParents.pl [OPTIONS] CUI
+Usage: getParents.pl [OPTIONS] [CUI|TERM]
 
 =head1 INPUT
 
 =head2 Required Arguments:
 
-=head3 CUI
+=head3 [CUI|TERM]
 
-A concept (CUI) from the Unified Medical Language System
+A concept (CUI) or a term from the Unified Medical Language System
 
 =head2 Optional Arguments:
 
@@ -55,7 +55,8 @@ Displays the version information.
 
 =head1 OUTPUT
 
-List of parent CUIs
+List of parent CUIs and their associated terms of the 
+given CUI or term.
 
 =head1 SYSTEM REQUIREMENTS
 
@@ -71,7 +72,7 @@ List of parent CUIs
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008,
+Copyright (c) 2007-2009,
 
  Bridget T. McInnes, University of Minnesota
  bthomson at cs.umn.edu
@@ -79,6 +80,12 @@ Copyright (c) 2007-2008,
  Ted Pedersen, University of Minnesota Duluth
  tpederse at d.umn.edu
 
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd@cs.utah.edu
+ 
+ Serguei Pakhomov, University of Minnesota Twin Cities
+ pakh0002@umn.edu
+
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
 Foundation; either version 2 of the License, or (at your option) any later
@@ -129,7 +136,7 @@ if( defined $opt_version ) {
 
 # At least 1 term should be given on the command line.
 if(scalar(@ARGV) < 1) {
-    print STDERR "No term was specified on the command line";
+    print STDERR "No term was specified on the command line\n";
     &minimalUsageNotes();
     exit;
 }
@@ -181,25 +188,48 @@ else {
 
 &errorCheck($umls);
 
-my $cui  = shift;
+my $input = shift;
+my $term  = $input;
 
-if($umls->validCui($cui)) {
-    print STDERR "ERROR: The concept ($cui) is not valid.\n";
-    exit;
-}
-
-my @cuis = $umls->getParents($cui); 
-
-&errorCheck($umls);
-
-print "CUI: $cui\n";
-if($#cuis < 0) {
-    print "This CUI does not have any parents\n";
+my @c = ();
+if($input=~/C[0-9]+/) {
+    push @c, $input;
+    ($term) = $umls->getTermList($input);
 }
 else {
-    foreach my $cui (@cuis) {
-	print "$cui\n";
+    @c = $umls->getConceptList($input);
+}
+
+&errorCheck($umls);
+ 
+my $printFlag = 0;
+
+foreach my $cui (@c) {
+
+    if($umls->validCui($cui)) {
+	print STDERR "ERROR: The concept ($cui) is not valid.\n";
+	exit;
     }
+
+    my @parents= $umls->getParents($cui); 
+
+    &errorCheck($umls);
+
+    if($#parents < 0) {
+	print "The term $term ($cui) does not have any parents\n";
+    }
+    else {
+	print "The parents of $term ($cui) are: \n";
+	foreach my $parent (@parents) {
+	    my ($t) = $umls->getTermList($parent);
+	    print "  $t($parent)\n";
+	} 
+    }
+    $printFlag = 1;
+}
+
+if(! ($printFlag) ) {
+    print "Input $input does not exist in this view of the UMLS.\n";
 }
 
 sub errorCheck
@@ -216,7 +246,7 @@ sub errorCheck
 ##############################################################################
 sub minimalUsageNotes {
     
-    print "Usage: getParents.pl [OPTIONS] CUI \n\n";
+    print "Usage: getParents.pl [OPTIONS] [CUI|TERM]\n";
     &askHelp();
     exit;
 }
@@ -227,11 +257,11 @@ sub minimalUsageNotes {
 sub showHelp() {
 
         
-    print "This is a utility that takes as input a CUI\n";
+    print "This is a utility that takes as input a CUI or a term\n";
     print "and returns all of its possible parents given\n";
     print "a specified set of sources\n\n";
   
-    print "Usage: getParents.pl [OPTIONS] CUI\n\n";
+    print "Usage: getParents.pl [OPTIONS] [CUI|TERM]\n\n";
 
     print "Options:\n\n";
 
@@ -256,7 +286,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getParents.pl,v 1.4 2009/01/25 00:19:40 btmcinnes Exp $';
+    print '$Id: getParents.pl,v 1.6 2009/02/09 17:48:37 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
