@@ -71,7 +71,7 @@ List of CUIs that are associated with the input term
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008,
+Copyright (c) 2007-2009,
 
  Bridget T. McInnes, University of Minnesota
  bthomson at cs.umn.edu
@@ -79,6 +79,12 @@ Copyright (c) 2007-2008,
  Ted Pedersen, University of Minnesota Duluth
  tpederse at d.umn.edu
 
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd@cs.utah.edu
+ 
+ Serguei Pakhomov, University of Minnesota Twin Cities
+ pakh0002@umn.edu
+
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
 Foundation; either version 2 of the License, or (at your option) any later
@@ -129,7 +135,7 @@ if( defined $opt_version ) {
 
 # At least 1 CUI should be given on the command line.
 if(scalar(@ARGV) < 1) {
-    print STDERR "No term was specified on the command line";
+    print STDERR "No term was specified on the command line\n";
     &minimalUsageNotes();
     exit;
 }
@@ -192,10 +198,15 @@ my @terms = $umls->getTermList($cui);
 
 &errorCheck($umls);
 
-print "The terms for CUI ($cui) are :\n";
-my $i = 1;
-foreach $term (@terms) {
-    print "$i. $term\n"; $i++;
+if($#terms < 0) {
+    print "There are no terms associated with $cui\n";
+}
+else {
+    print "The terms for CUI ($cui) are :\n";
+    my $i = 1;
+    foreach $term (@terms) {
+	print "$i. $term\n"; $i++;
+    }
 }
 
 sub errorCheck
@@ -212,7 +223,7 @@ sub errorCheck
 ##############################################################################
 sub minimalUsageNotes {
     
-    print "Usage: queryCui.pl [OPTIONS] CUI \n\n";
+    print "Usage: queryCui.pl [OPTIONS] CUI \n";
     &askHelp();
     exit;
 }
@@ -251,7 +262,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: queryCui.pl,v 1.8 2009/01/24 15:16:34 btmcinnes Exp $';
+    print '$Id: queryCui.pl,v 1.10 2009/02/09 17:48:37 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
